export { default as uniqBy } from 'lodash/uniqBy.js';
/**
 * Make an array unique by removing duplicate entries.
 * @param ar - Array to make unique
 * @returns A unique array
 */
export declare function uniqueArray<T>(ar: T[]): T[];
/**
 * Is Some Of This Array In That Array?
 * Are any of the items in arrayA in arrayB?
 */
export declare function hasItemsInItems<T extends string | number | boolean>(arrayA: T[], arrayB: T[]): boolean;
/**
 * Used to ensure that the `id` prop in each object in an array is unique
 */
export declare function assertUniqueIdInArray<T, Key extends string & keyof T>({ items, key, errorMsgPrefix, }: {
    items: T[] | readonly T[];
    /** Can be `id` or `value` */
    key: Key;
    errorMsgPrefix?: string;
}): void;
export declare function isArrayOfStringsUnique(arr: string[]): boolean;
export declare function getNonUniqueStringsFromArray(arr: string[]): string[];
/**
 * Converts an array of objects to a dictionary using a specified key.
 *
 * @see {@link dictionaryToArray}
 *
 * @example
 * const array = [
 *   { id: '123', name: 'foo' },
 *   { id: '456', name: 'bar' }
 * ];
 * const result = arrayToDictionary(array);
 * // Result: { '123': { name: 'foo' }, '456': { name: 'bar' } }
 *
 * const customResult = arrayToDictionary(array, 'name');
 * // Result: { 'foo': { id: '123' }, 'bar': { id: '456' } }
 */
export declare function arrayToDictionary<T extends Record<string, unknown>, K extends keyof T & string>(
/**
 * The array of objects to convert
 */
array: T[], 
/**
 * The property to use as the dictionary key
 */
keyProp: K): Record<string, T>;
//# sourceMappingURL=arrays.d.ts.map