import { Patch, applyPatches, produceWithPatches, produce, isDraft, type Draft, type Objectish } from 'immer';
export { produce, produceWithPatches, applyPatches, isDraft };
export type { Patch, Draft };
/**
 * Take an array of Immer patches and compress them down to the smallest amount of patches
 * @link https://medium.com/@dedels/using-immer-to-compress-immer-patches-f382835b6c69
 */
export declare function compressPatches<Data extends Objectish>({ baseData, patches: allPatches, }: {
    baseData: Data;
    patches: Patch[][] | Patch[];
}): readonly [Data, Patch[], Patch[]];
/**
 * Loop over changes to applyPatches in small batches (safer) instead of all at once
 * If there are errors, it will skip that change and continue on
 */
export declare function applyPatchesSafely<Data extends Objectish>({ data, changes, logError, logAppClientData, }: {
    data: Data;
    changes: {
        patches: Patch[];
    }[];
    logError?: (msg: unknown, ...optionalMsgs: unknown[]) => void;
    logAppClientData?: boolean;
}): Data;
//# sourceMappingURL=immer.d.ts.map